function addEvent(eventType, element, handler) {
  element.addEventListener(eventType, handler, false);
}

function removeEvent(eventType, element, handler) {
  element.removeEventListener(eventType, handler, false);
}

function parseDOMString(str, type = 'text/html') {
  const parser = new DOMParser();
  const elDoc = parser.parseFromString(str, type);
  return elDoc.firstChild;
}

function createElement(elementName, props = {}) {
  const element = document.createElement(elementName);
  Object.entries(props).forEach(([key, val]) => {
    element[key] = val;
  });
  return element;
}

function removeElement(element, events = {}) {
  Object.entries(events).forEach(([key, val]) => {
    removeEvent(key, element, val);
  });
  element.parentNode.removeChild(element);
  element = null;
}

function hasText(element, tag) {
  return element.textContent === tag;
}

function queryElement(element) {
  let queryResult = undefined;
  if (
    element !== null &&
    typeof element === 'object' &&
    element.nodeType === 1 &&
    typeof element.nodeName === 'string'
  ) {
    queryResult = element;
  } else if (typeof element === 'string') {
    queryResult = document.getElementById(element);
  }

  if (!queryResult) {
    throw new Error('Invalid element');
  }

  return queryResult;
}

export { removeEvent, addEvent, queryElement, createElement, parseDOMString, removeElement, hasText };
